@@ -1,6 +1,6 @@
 /**-*-c++-*-****************************************************************
                              -------------------
-    cvs         : $Id: ktoblzcheck.h,v 1.14 2005/11/29 09:17:42 cstim Exp $
+    cvs         : $Id: ktoblzcheck.h.in,v 1.1 2006/02/13 14:14:14 cstim Exp $
     begin       : Sat Aug 10 2002
     copyright   : (C) 2002, 2003 by Fabian Kaiser and Christian Stimming
     email       : fabian@openhbci.de
@@ -27,6 +27,11 @@
 #ifndef KTOBLZCHECK_H
 #define KTOBLZCHECK_H
 
+/** The major version number of this library */
+#define KTOBLZCHECK_VERSION_MAJOR 1
+/** The minor version number of this library */
+#define KTOBLZCHECK_VERSION_MINOR 10
+
 /** @file 
  * @brief Checking of German BLZ and account numbers
  *
