@@ -32,6 +32,8 @@
 #include <fstream>
 #include <iostream>
 #include <algorithm>
+#include <cassert>
+#include <cstdio>
 
 // The actual algorithms for number checking are there
 #include "algorithms.h"
@@ -68,10 +70,10 @@ AccountNumberCheck::Record::Record(const char *id,
 				   const char *meth, 
 				   const char *name, 
 				   const char *loc)
-  : bankId(atol(id))
-   , method(meth)
-   , bankName(name)
-   , location(loc)
+  : bankId(id ? atol(id) : 0)
+   , method(meth ? meth : "")
+   , bankName(name ? name : "")
+   , location(loc ? loc : "")
 {
 }
 
@@ -96,17 +98,21 @@ std::string AccountNumberCheck::resultToString(Result r)
 AccountNumberCheck::AccountNumberCheck() 
     : data() // std::map doesn't take size as argument
 {
-   string registry_path = accnum_getRegKey("datadir");
-   string data_path = BANKDATA_PATH;
-   string filename = (registry_path.empty() ? data_path : registry_path)
-      + 
+   std::string registry_path(accnum_getRegKey("datadir"));
+   std::string data_path(BANKDATA_PATH);
+   std::string dirsep(
 #if OS_WIN32
       "\\"
 #else
       "/"
 #endif
-      + std::string("bankdata.txt");
-   readFile(filename);
+      );
+   std::string bankdata_filename("bankdata.txt");
+
+   std::string full_filename(
+      (registry_path.empty() ? data_path : registry_path)
+      + dirsep + bankdata_filename);
+   readFile(full_filename);
 }
 
 AccountNumberCheck::AccountNumberCheck(const string& filename) 
@@ -128,6 +134,15 @@ AccountNumberCheck::~AccountNumberCheck()
 // From 2006-06-05 onwards the field "PLACE" has 35 instead of 29
 // characters!
 
+//#define ARRAY_BOUNDS_CHECK 1
+#undef ARRAY_BOUNDS_CHECK
+
+#ifdef ARRAY_BOUNDS_CHECK
+#  define PLUSONE +1
+#else
+#  define PLUSONE
+#endif
+
 void 
 AccountNumberCheck::readFile(const string &filename) 
 {
@@ -146,10 +161,18 @@ AccountNumberCheck::readFile(const string &filename)
      return;
   }
 
-  char blz[BLZ_SIZE];
-  char method[METHOD_SIZE];
-  char name[NAME_SIZE];
-  char place[PLACE_SIZE];
+  // We better use heap-allocated arrays because some weird stack
+  // corruption has been reported with ktoblzcheck-1.8 on Debian.
+  char *blz = new char[BLZ_SIZE PLUSONE];
+  char *method = new char[METHOD_SIZE PLUSONE];
+  char *name = new char[NAME_SIZE PLUSONE];
+  char *place = new char[PLACE_SIZE PLUSONE];
+#ifdef ARRAY_BOUNDS_CHECK
+  blz[BLZ_SIZE]=17;
+  method[METHOD_SIZE]=17;
+  name[NAME_SIZE]=17;
+  place[PLACE_SIZE]=17;
+#endif
 
   while (fgets(blz, BLZ_SIZE, istr))
   {
@@ -166,7 +189,17 @@ AccountNumberCheck::readFile(const string &filename)
      // ascending BLZ
      data.insert(data.end(), banklist_type::value_type(newRecord->bankId, newRecord));
      if (fgetc(istr) == EOF) break; // remove delimiter
+#ifdef ARRAY_BOUNDS_CHECK
+     assert(blz[BLZ_SIZE]==17);
+     assert(method[METHOD_SIZE]==17);
+     assert(name[NAME_SIZE]==17);
+     assert(place[PLACE_SIZE]==17);
+#endif
   }
+  delete[] blz;
+  delete[] method;
+  delete[] name;
+  delete[] place;
   fclose(istr);
 }
 
@@ -190,6 +223,8 @@ void AccountNumberCheck::createIndex() {
 
 
 // Function object for the predicate of matching a job result
+#if 0
+// currently unused; was only used for std::vector et al
 class MatchBlz {
     unsigned long blz;
   public:
@@ -199,6 +234,7 @@ class MatchBlz {
 	return r && (r->bankId == blz);
     }
 };
+#endif
 
 const AccountNumberCheck::Record& 
 AccountNumberCheck::findBank(const string& bankId) const 
